@@ -31,11 +31,11 @@ class Tpu(Base):
         self.logger.Debug (4, 'TPU init params: {}'.format(options))
         
         self.processor='tpu'
-        self.lock_maximum=options.get(self.processor+'_max_processes') or 1
-        self.lock_name='pyzm_'+self.processor+'_lock'
-        self.lock_timeout = options.get(self.processor+'_max_lock_wait') or 120
+        self.lock_maximum=int(options.get(self.processor+'_max_processes') or 1)
+        self.lock_name='pyzm_uid{}_{}_lock'.format(os.getuid(),self.processor)
+        self.lock_timeout = int(options.get(self.processor+'_max_lock_wait') or 120)
 
-        self.logger.Debug (2,f'Semaphore: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
+        self.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
         self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
         self.is_locked = False
         self.model = None
@@ -43,25 +43,25 @@ class Tpu(Base):
 
     def acquire_lock(self):
         if self.is_locked:
-            self.logger.Debug (2, '{} Lock already acquired'.format(self.lock_name))
+            self.logger.Debug (2, '{} portalock already acquired'.format(self.lock_name))
             return
         try:
-            self.logger.Debug (2,'Waiting for TPU lock...')
+            self.logger.Debug (2,'Waiting for {} portalock...'.format(self.lock_name))
             self.lock.acquire()
-            self.logger.Debug (2,'Got TPU Lock')
+            self.logger.Debug (2,'Got {} portalock'.format(self.lock_name))
             self.is_locked = True
 
         except portalocker.AlreadyLocked:
-            self.logger.Error ('Timeout waiting for {} lock for {} seconds'.format(self.processor, self.lock_timeout))
-            raise ValueError ('Timeout waiting for {} lock for {} seconds'.format(self.processor, self.lock_timeout))
+            self.logger.Error ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
+            raise ValueError ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
 
     def release_lock(self):
         if not self.is_locked:
-            self.logger.Debug (2, '{} Lock already released'.format(self.lock_name))
+            self.logger.Debug (2, '{} portalock already released'.format(self.lock_name))
             return
         self.lock.release()
         self.is_locked = False
-        self.logger.Debug (2,'Released TPU lock')
+        self.logger.Debug (2,'Released portalock {}'.format(self.lock_name))
 
 
     def populate_class_labels(self):
@@ -98,26 +98,31 @@ class Tpu(Base):
         if self.options.get('auto_lock',True):
             self.acquire_lock()
 
-        if not self.model:
-           self.load_model()
+        try:
+            if not self.model:
+                self.load_model()
+
+            self.logger.Debug(1,
+                '|---------- TPU (input image: {}w*{}h) ----------|'
+                .format(Width, Height))
+            start = datetime.datetime.now()
+            
+            _, scale = common.set_resized_input(
+                self.model, img.size, lambda size: img.resize(size, Image.ANTIALIAS))
+            self.model.invoke()
+            objs = detect.get_objects(self.model, float(self.options.get('object_min_confidence')), scale)
 
-        self.logger.Debug(1,
-            '|---------- TPU (input image: {}w*{}h) ----------|'
-            .format(Width, Height))
-        start = datetime.datetime.now()
         
-        _, scale = common.set_resized_input(
-            self.model, img.size, lambda size: img.resize(size, Image.ANTIALIAS))
-        self.model.invoke()
-        objs = detect.get_objects(self.model, self.options.get('object_min_confidence'), scale)
+            #outs = self.model.detect_with_image(img, threshold=int(self.options.get('object_min_confidence')),
+            #        keep_aspect_ratio=True, relative_coord=False)
+            diff_time = (datetime.datetime.now() - start)
 
-      
-        #outs = self.model.detect_with_image(img, threshold=int(self.options.get('object_min_confidence')),
-        #        keep_aspect_ratio=True, relative_coord=False)
-        diff_time = (datetime.datetime.now() - start)
-
-        if self.options.get('auto_lock',True):
-            self.release_lock()
+            if self.options.get('auto_lock',True):
+                self.release_lock()
+        except:
+            if self.options.get('auto_lock',True):
+                self.release_lock()
+            raise
 
         self.logger.Debug(
             1,'Coral TPU detection took: {}'.format(diff_time))
