@@ -67,7 +67,7 @@ class DetectSequence(Base):
                                 'object_processor': 'gpu',
                                 # These are optional below. Default is 416. Change if your model is trained for larger sizes
                                 'model_width': 416, 
-                                'model_height: 416
+                                'model_height': 416
                             }]
                         },
 
@@ -77,6 +77,10 @@ class DetectSequence(Base):
                                 'same_model_sequence_strategy': 'first'
                             },
                             'sequence': [{
+                                # if max_size is specified, not matter what
+                                # the resize value in stream_options, it will be rescaled down to this
+                                # value if needed
+                                'max_size':800, 
                                 'face_detection_framework': 'dlib',
                                 'known_images_path': '/var/lib/zmeventnotification/known_faces',
                                 'face_model': 'cnn',
@@ -123,6 +127,7 @@ class DetectSequence(Base):
         self.models = {}
         self.media = None
         self.has_rescaled = False
+        self.ml_overrides = {}
 
     def _load_models(self, sequences):
         #print (f'***** {sequences}')
@@ -266,12 +271,12 @@ class DetectSequence(Base):
         return new_bbox, new_label, new_conf, new_err
 
 
-    def detect_stream(self, stream, options={}):
+    def detect_stream(self, stream, options={}, ml_overrides={}):
         """Implements detection on a video stream
 
         Args:
             stream (string): location of media (file, url or event ID)
-            api (object): instance of the API if the stream need to route via ZM
+            ml_overrides(string): Ignore it. You will almost never need it. zm_detect uses it for ugly foo
             options (dict, optional): Various options that control the detection process. Defaults to {}:
 
                 - download (boolean): if True, will download video before analysis. Defaults to False
@@ -319,7 +324,7 @@ class DetectSequence(Base):
         """
 
         
-
+        self.ml_overrides = ml_overrides
         self.stream_options = options
         frame_strategy = self.stream_options.get('frame_strategy', 'most_models' )
         all_matches = []
@@ -406,7 +411,6 @@ class DetectSequence(Base):
                     self.logger.Debug(3,'--------- Frame:{} Running variation: #{} -------------'.format(self.media.get_last_read_frame(),cnt))
                     cnt +=1
                     try:
-                       
                         _b,_l,_c = m.detect(image=frame)
                         self.logger.Debug(4,'This model iteration inside {} found: labels: {},conf:{}'.format(seq, _l, _c))
                     except Exception as e:
