@@ -19,7 +19,7 @@ from pyzm.helpers.Base import Base
 import portalocker
 import re
 from pyzm.helpers.Media import MediaStream
-
+import imutils
 
 class Face(Base):
     def __init__(self, logger=None, options={},upsample_times=1, num_jitters=0, model='hog'):
@@ -46,11 +46,13 @@ class Face(Base):
         self.options = options
         self.is_locked = False
 
-        self.lock_maximum=options.get(self.processor+'_max_processes') or 1
-        self.lock_timeout = options.get(self.processor+'_max_lock_wait') or 120
+        self.lock_maximum=int(options.get(self.processor+'_max_processes') or 1)
+        self.lock_timeout = int(options.get(self.processor+'_max_lock_wait') or 120)
         
-        self.lock_name='pyzm_'+self.processor+'_lock'
-        self.logger.Debug (2,f'Semaphore: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
+        #self.lock_name='pyzm_'+self.processor+'_lock'
+        self.lock_name='pyzm_uid{}_{}_lock'.format(os.getuid(),self.processor)
+
+        self.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
         self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
         
 
@@ -95,27 +97,26 @@ class Face(Base):
 
     def acquire_lock(self):
         if self.is_locked:
-            self.logger.Debug (2, '{} Lock already acquired'.format(self.lock_name))
+            self.logger.Debug (2, '{} portalock already acquired'.format(self.lock_name))
             return
         try:
-            self.logger.Debug (2,f'Waiting for {self.processor} lock...')
+            self.logger.Debug (2,f'Waiting for {self.lock_name} portalock...')
             self.lock.acquire()
-            self.logger.Debug (2,f'Got {self.processor} lock for initialization...')
-           
-            self.lock.release()
-            self.logger.Debug(2,f'{self.processor} lock released')
+            self.logger.Debug (2,f'Got {self.lock_name} lock...')
+            self.is_locked = True
+
         except portalocker.AlreadyLocked:
-            self.logger.Error ('Timeout waiting for {} lock for {} seconds'.format(self.processor, self.lock_timeout))
-            raise ValueError ('Timeout waiting for {} lock for {} seconds'.format(self.processor, self.lock_timeout))
+            self.logger.Error ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
+            raise ValueError ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
 
 
     def release_lock(self):
         if not self.is_locked:
-            self.logger.Debug (1, '{} Lock already released'.format(self.lock_name))
+            self.logger.Debug (1, '{} portalock already released'.format(self.lock_name))
             return
         self.lock.release()
         self.is_locked = False
-        self.logger.Debug (1,'Released lock')
+        self.logger.Debug (1,'Released {} portalock'.format(self.lock_name))
 
     def get_classes(self):
         if self.knn:
@@ -141,6 +142,22 @@ class Face(Base):
         self.logger.Debug(
             1,'|---------- Face recognition (input image: {}w*{}h) ----------|'.
             format(Width, Height))
+
+        downscaled =  False
+        upsize_xfactor = None
+        upsize_yfactor = None
+        max_size = self.options.get('max_size', Width)
+        old_image = None
+
+        if Width > max_size:
+            downscaled = True
+            self.logger.Debug (2, 'Scaling image down to max size: {}'.format(max_size))
+            old_image = image.copy()
+            image = imutils.resize(image,width=max_size)
+            newHeight, newWidth = image.shape[:2]
+            upsize_xfactor = Width/newWidth
+            upsize_yfactor = Height/newHeight
+
         labels = []
         classes = []
         conf = []
@@ -187,7 +204,7 @@ class Face(Base):
         if self.knn:
             closest_distances = self.knn.kneighbors(face_encodings, n_neighbors=1)
             are_matches = [
-                closest_distances[0][i][0] <= self.options.get('face_recog_dist_threshold')
+                closest_distances[0][i][0] <= int(self.options.get('face_recog_dist_threshold',0.6))
                 for i in range(len(face_locations))
                 
             ]
@@ -208,20 +225,29 @@ class Face(Base):
         matched_face_names = []
         matched_face_rects = []
 
+        if downscaled:
+            self.logger.Debug (2,'Scaling image back up to {}'.format(Width))
+            image = old_image
+            new_face_locations = []
+            for loc in face_locations:
+                a,b,c,d=loc
+                a = round(a * upsize_yfactor)
+                b = round(b * upsize_xfactor)
+                c = round(c * upsize_yfactor)
+                d = round(d * upsize_xfactor)
+                new_face_locations.append((a,b,c,d))
+            face_locations = new_face_locations
+
+
         for pred, loc, rec in zip(prediction_labels,
                                   face_locations, are_matches):
             label = pred if rec else self.options.get('unknown_face_name', 'unknown')
             if not rec and self.options.get('save_unknown_faces') == 'yes':
                 h, w, c = image.shape
-                x1 = max(loc[3] - self.options.get('save_unknown_faces_leeway_pixels'),
-                         0)
-                y1 = max(loc[0] - self.options.get('save_unknown_faces_leeway_pixels'),
-                         0)
-
-                x2 = min(loc[1] + self.options.get('save_unknown_faces_leeway_pixels'),
-                         w)
-                y2 = min(loc[2] + self.options.get('save_unknown_faces_leeway_pixels'),
-                         h)
+                x1 = max(loc[3] - int(self.options.get('save_unknown_faces_leeway_pixels',0)),0)
+                y1 = max(loc[0] - int(self.options.get('save_unknown_faces_leeway_pixels',0)),0)
+                x2 = min(loc[1] + int(self.options.get('save_unknown_faces_leeway_pixels',0)), w)
+                y2 = min(loc[2] + int(self.options.get('save_unknown_faces_leeway_pixels',0)),h)
                 #print (image)
                 crop_img = image[y1:y2, x1:x2]
                 # crop_img = image
@@ -234,6 +260,7 @@ class Face(Base):
                             self.options.get('save_unknown_faces_leeway_pixels'), unf))
                 cv2.imwrite(unf, crop_img)
 
+            
             matched_face_rects.append([loc[3], loc[0], loc[1], loc[2]])
             matched_face_names.append(label)
             #matched_face_names.append('face:{}'.format(label))
