@@ -7,6 +7,7 @@ import datetime
 import re
 from pyzm.helpers.Base import Base
 import portalocker
+import os
 # Class to handle Yolo based detection
 
 
@@ -25,37 +26,39 @@ class Yolo(Base):
         self.logger.Debug (4, 'Yolo init params: {}'.format(options))
 
         self.processor=self.options.get('object_processor') or 'cpu'
-        self.lock_maximum=options.get(self.processor+'_max_processes') or 1
-        self.lock_timeout = options.get(self.processor+'_max_lock_wait') or 120
+        self.lock_maximum=int(options.get(self.processor+'_max_processes') or 1)
+        self.lock_timeout = int(options.get(self.processor+'_max_lock_wait') or 120)
         
-        self.lock_name='pyzm_'+self.processor+'_lock'
-        self.logger.Debug (2,f'Semaphore: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
+        #self.lock_name='pyzm_'+self.processor+'_lock'
+        self.lock_name='pyzm_uid{}_{}_lock'.format(os.getuid(),self.processor)
+
+        self.logger.Debug (2,f'portalock: max:{self.lock_maximum}, name:{self.lock_name}, timeout:{self.lock_timeout}')
         self.lock = portalocker.BoundedSemaphore(maximum=self.lock_maximum, name=self.lock_name,timeout=self.lock_timeout)
         self.model_height = self.options.get('model_height', 416)
         self.model_width = self.options.get('model_width', 416)
          
     def acquire_lock(self):
         if self.is_locked:
-            self.logger.Debug(2, '{} Lock already acquired'.format(self.lock_name))
+            self.logger.Debug(2, '{} portalock already acquired'.format(self.lock_name))
             return
         try:
-            self.logger.Debug (2,f'Waiting for {self.processor} lock...')
+            self.logger.Debug (2,f'Waiting for {self.lock_name} portalock...')
             self.lock.acquire()
-            self.logger.Debug (2,f'Got {self.processor} lock ..')
+            self.logger.Debug (2,f'Got {self.lock_name} portalock')
             self.is_locked = True
            
         except portalocker.AlreadyLocked:
-            self.logger.Error ('Timeout waiting for {} lock for {} seconds'.format(self.processor, self.lock_timeout))
-            raise ValueError ('Timeout waiting for {} lock for {} seconds'.format(self.processor, self.lock_timeout))
+            self.logger.Error ('Timeout waiting for {} portalock for {} seconds'.format(self.lock_name, self.lock_timeout))
+            raise ValueError ('Timeout waiting for {} portallock for {} seconds'.format(self.lock_name, self.lock_timeout))
 
 
     def release_lock(self):
         if not self.is_locked:
-            self.logger.Debug (2, '{} Lock already released'.format(self.lock_name))
+            self.logger.Debug (2, '{} portalock already released'.format(self.lock_name))
             return
         self.lock.release()
         self.is_locked = False
-        self.logger.Debug (2,'Released lock')
+        self.logger.Debug (2,'Released {} portalock'.format(self.lock_name))
 
 
         
@@ -105,35 +108,55 @@ class Yolo(Base):
         return output_layers
 
     def detect(self, image=None):
-
         Height, Width = image.shape[:2]
-        
+        downscaled =  False
+        upsize_xfactor = None
+        upsize_yfactor = None
+        max_size = self.options.get('max_size', Width)
+        old_image = None
+
+        if Width > max_size:
+            downscaled = True
+            self.logger.Debug (2, 'Scaling image down to max size: {}'.format(max_size))
+            old_image = image.copy()
+            image = imutils.resize(image,width=max_size)
+            newHeight, newWidth = image.shape[:2]
+            upsize_xfactor = Width/newWidth
+            upsize_yfactor = Height/newHeight        
+
 
         if self.options.get('auto_lock',True):
             self.acquire_lock()
 
-        if not self.net:
-            self.load_model()
+        try:
+            if not self.net:
+                self.load_model()
+
+            self.logger.Debug(
+                1,'|---------- YOLO (input image: {}w*{}h, model resize dimensions: {}w*{}h) ----------|'
+                .format(Width, Height, self.model_width, self.model_height))
 
-        self.logger.Debug(
-            1,'|---------- YOLO (input image: {}w*{}h, resized to: {}w*{}h) ----------|'
-            .format(Width, Height, self.model_width, self.model_height))
-        scale = 0.00392  # 1/255, really. Normalize inputs.
             
-        start = datetime.datetime.now()
-        ln = self.net.getLayerNames()
-        ln = [ln[i[0] - 1] for i in self.net.getUnconnectedOutLayers()]
-        blob = cv2.dnn.blobFromImage(image,
-                                    scale, (self.model_width, self.model_height), (0, 0, 0),
-                                    True,
-                                    crop=False)
-        
-        self.net.setInput(blob)
-        outs = self.net.forward(ln)
+            scale = 0.00392  # 1/255, really. Normalize inputs.
+                
+            start = datetime.datetime.now()
+            ln = self.net.getLayerNames()
+            ln = [ln[i[0] - 1] for i in self.net.getUnconnectedOutLayers()]
+            blob = cv2.dnn.blobFromImage(image,
+                                        scale, (self.model_width, self.model_height), (0, 0, 0),
+                                        True,
+                                        crop=False)
+            
+            self.net.setInput(blob)
+            outs = self.net.forward(ln)
+
+            if self.options.get('auto_lock',True):
+                self.release_lock()
+        except:
+            if self.options.get('auto_lock',True):
+                self.release_lock()
+            raise
 
-        if self.options.get('auto_lock',True):
-            self.release_lock()
-            self.logger.Debug(2,'detect lock released')
         diff_time = (datetime.datetime.now() - start)
         self.logger.Debug(
             1,'YOLO detection took: {} milliseconds'.format(diff_time))
@@ -147,8 +170,8 @@ class Yolo(Base):
         conf_threshold = 0.2
 
         # first nms filter out with a yolo confidence of 0.2 (or less)
-        if self.options.get('object_min_confidence') < conf_threshold:
-            conf_threshold = self.options.get('object_min_confidence')
+        if float(self.options.get('object_min_confidence')) < conf_threshold:
+            conf_threshold = float(self.options.get('object_min_confidence'))
 
         for out in outs:
             for detection in out:
@@ -195,5 +218,13 @@ class Yolo(Base):
             label.append(str(self.classes[class_ids[i]]))
             conf.append(confidences[i])
            
+        if downscaled:
+            self.logger.Debug (2,'Scaling image back up to {}'.format(Width))
+            image = old_image
+            for box in bbox:
+                box[0] = round (box[0] * upsize_xfactor)
+                box[1] = round (box[1] * upsize_yfactor)
+                box[2] = round (box[2] * upsize_xfactor)
+                box[3] = round (box[3] * upsize_yfactor)
         
         return bbox, label, conf
